summaryrefslogtreecommitdiff
path: root/libdiskfs/boot-start.c
diff options
context:
space:
mode:
Diffstat (limited to 'libdiskfs/boot-start.c')
-rw-r--r--libdiskfs/boot-start.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libdiskfs/boot-start.c b/libdiskfs/boot-start.c
index a93a6227..29b8acc6 100644
--- a/libdiskfs/boot-start.c
+++ b/libdiskfs/boot-start.c
@@ -499,8 +499,8 @@ diskfs_S_fsys_init (struct diskfs_control *pt,
return EOPNOTSUPP;
initdone = 1;
- /* init is single-threaded, so we must reply to its RPC before doing
- anything which might attempt to send an RPC to init. */
+ /* startup is single-threaded, so we must reply to its RPC before doing
+ anything which might attempt to send an RPC to startup. */
fsys_init_reply (reply, replytype, 0);
/* Allocate our references here; _hurd_init will consume a reference